IDSExpandableCard class

A customizable expandable card widget with a title, description, and expand/collapse icons.

Inheritance

Constructors

IDSExpandableCard({Key? key, required String cardTitle, required String cardDescription, TextStyle? titleTextStyle, TextStyle? descriptionTextStyle, required Widget expandIcon, required Widget collapseIcon})
Creates an IDSExpandableCard.
const

Properties

cardDescription → String
The description or detailed content shown when the card is expanded.
final
cardTitle → String
The main title text displayed at the top of the card.
final
collapseIcon → Widget
The icon widget shown when the card is expanded.
final
descriptionTextStyle → TextStyle?
An optional custom text style for the cardDescription.
final
expandIcon → Widget
The icon widget shown when the card is collapsed.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleTextStyle → TextStyle?
An optional custom text style for the cardTitle.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → IDSExpandableCardState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited